@@ -69,7 +69,11 @@ def resolve_sources(hub, dnames: List[str], raw_cli: Dict[str, Any]):
             source = opt_data.get("source")
             if not source:
                 continue
-            # Remove the option from it's parent and add it to the config of the source
+            if source not in raw_cli:
+                raw_cli[source] = {}
+            if "CONFIG" not in raw_cli[source]:
+                raw_cli[source]["CONFIG"] = {}
+            # Remove the option from its parent and add it to the config of the source
             raw_cli[name]["CONFIG"].pop(opt_name)
             if opt_name in raw_cli[source]["CONFIG"]:
                 raw_cli[source]["CONFIG"][opt_name].update(opt_data)
