@@ -16,5 +16,8 @@ def run(hub, primary):
 
 
 def get(hub, primary):
-    mod = importlib.import_module(f"{primary}.version")
-    return mod.version
+    try:
+        mod = importlib.import_module(f"{primary}.version")
+        return mod.version
+    except ModuleNotFoundError as e:
+        hub.log.warning(f"Could not find version.py for '{primary}': {e}")
